==> haskell-postgresql-binary-0.12.1.1-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-postgresql-binary.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgresql-binary
version: 0.12.1.1
id: postgresql-binary-0.12.1.1-CDTJ7SR7GP24cVVbngnZY5
key: postgresql-binary-0.12.1.1-CDTJ7SR7GP24cVVbngnZY5
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/postgresql-binary
synopsis: Encoders and decoders for the PostgreSQL'\''s binary format
description:
    An API for dealing with PostgreSQL'\''s binary data format.
    .
    It can be used to implement performant bindings to Postgres.
    E.g., <http://hackage.haskell.org/package/hasql "hasql">
    is based on this library.
    .
    It supports all Postgres versions starting from 8.3
    and is tested against 8.3, 9.3 and 9.5
    with the @integer_datetimes@ setting off and on.
category: PostgreSQL, Database, Codecs, Parsing
abi: 21701fb2a02f04a5901a6ed67d44503c
exposed: True
exposed-modules:
    PostgreSQL.Binary.Data PostgreSQL.Binary.Decoding
    PostgreSQL.Binary.Encoding
hidden-modules: PostgreSQL.Binary.Encoding.Builders
                PostgreSQL.Binary.Prelude PostgreSQL.Binary.Integral
                PostgreSQL.Binary.Interval PostgreSQL.Binary.Numeric
                PostgreSQL.Binary.Time PostgreSQL.Binary.Inet
                PostgreSQL.Binary.BuilderPrim
import-dirs: /usr/lib/ghc-8.4.3/site-local/postgresql-binary-0.12.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/postgresql-binary-0.12.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/postgresql-binary-0.12.1.1
hs-libraries: HSpostgresql-binary-0.12.1.1-CDTJ7SR7GP24cVVbngnZY5
depends:
    binary-parser-0.5.5-DOktvusN2D8DgvU8lt7P2M
    bytestring-strict-builder-0.4.5.1-Fzz2umvqJk67wpKgzMS5MH
    aeson-1.3.1.1-8UOGGWrOftS8IR9IO8SVX0
    uuid-1.3.13-3mVsma00PlkLLPrLVUhxJq time-1.8.0.2
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul bytestring-0.10.8.2
    text-1.2.3.0 vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    network-ip-0.3.0.2-6AMB7LZoXGW5VNnZHhCQqV
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
    containers-0.5.11.0 loch-th-0.2.2-5Eq2dK8L8YJJWK4HNR9w70
    placeholders-0.1-4bE0Visrk2tFnTI1hMfyUR transformers-0.5.5.0
    base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7 base-4.11.1.0
abi-depends: binary-parser-0.5.5-DOktvusN2D8DgvU8lt7P2M=506126636f4bf9f20373b4ba483394f0
             bytestring-strict-builder-0.4.5.1-Fzz2umvqJk67wpKgzMS5MH=2ad70980710a5ba2958a64744a7f5bf0
             aeson-1.3.1.1-8UOGGWrOftS8IR9IO8SVX0=f52d85e32d32c3f9df6cda1e0fc08911
             uuid-1.3.13-3mVsma00PlkLLPrLVUhxJq=9189546b75a5e679abf4b8f1f323139c
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=67146f6b2fe2f883da537f78817eb0dd
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             network-ip-0.3.0.2-6AMB7LZoXGW5VNnZHhCQqV=485c9164a83e7e6dfc2d42d953cae629
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             loch-th-0.2.2-5Eq2dK8L8YJJWK4HNR9w70=00fd0dc72b72ed83b5d37907b4600d8e
             placeholders-0.1-4bE0Visrk2tFnTI1hMfyUR=c1d872831901a2463250620e0e797580
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=6440a7e70ad5450b51ffd7c9c4277ed3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-postgresql-binary/html/postgresql-binary.haddock
haddock-html: /usr/share/doc/haskell-postgresql-binary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-postgresql-binary-0.12.1.1-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-postgresql-binary.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgresql-binary
version: 0.12.1.1
id: postgresql-binary-0.12.1.1-KPBm20N5nJiCJvISDyEeo8
key: postgresql-binary-0.12.1.1-KPBm20N5nJiCJvISDyEeo8
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/postgresql-binary
synopsis: Encoders and decoders for the PostgreSQL'\''s binary format
description:
    An API for dealing with PostgreSQL'\''s binary data format.
    .
    It can be used to implement performant bindings to Postgres.
    E.g., <http://hackage.haskell.org/package/hasql "hasql">
    is based on this library.
    .
    It supports all Postgres versions starting from 8.3
    and is tested against 8.3, 9.3 and 9.5
    with the @integer_datetimes@ setting off and on.
category: PostgreSQL, Database, Codecs, Parsing
abi: c6b9705222795caeca868491ae002a50
exposed: True
exposed-modules:
    PostgreSQL.Binary.Data PostgreSQL.Binary.Decoding
    PostgreSQL.Binary.Encoding
hidden-modules: PostgreSQL.Binary.Encoding.Builders
                PostgreSQL.Binary.Prelude PostgreSQL.Binary.Integral
                PostgreSQL.Binary.Interval PostgreSQL.Binary.Numeric
                PostgreSQL.Binary.Time PostgreSQL.Binary.Inet
                PostgreSQL.Binary.BuilderPrim
import-dirs: /usr/lib/ghc-8.4.3/site-local/postgresql-binary-0.12.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/postgresql-binary-0.12.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/postgresql-binary-0.12.1.1
hs-libraries: HSpostgresql-binary-0.12.1.1-KPBm20N5nJiCJvISDyEeo8
depends:
    binary-parser-0.5.5-DOktvusN2D8DgvU8lt7P2M
    bytestring-strict-builder-0.4.5.1-5SjTO7kuhVoF0VfhI0Sfcu
    aeson-1.3.1.1-ArWpZy1DbZ6Lxt3YgJqPBO
    uuid-1.3.13-3mVsma00PlkLLPrLVUhxJq time-1.8.0.2
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul bytestring-0.10.8.2
    text-1.2.3.0 vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    network-ip-0.3.0.2-6AMB7LZoXGW5VNnZHhCQqV
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
    containers-0.5.11.0 loch-th-0.2.2-5Eq2dK8L8YJJWK4HNR9w70
    placeholders-0.1-4bE0Visrk2tFnTI1hMfyUR transformers-0.5.5.0
    base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7 base-4.11.1.0
abi-depends: binary-parser-0.5.5-DOktvusN2D8DgvU8lt7P2M=506126636f4bf9f20373b4ba483394f0
             bytestring-strict-builder-0.4.5.1-5SjTO7kuhVoF0VfhI0Sfcu=56ef270c8788071a7d7cf46f2248884f
             aeson-1.3.1.1-ArWpZy1DbZ6Lxt3YgJqPBO=63ce14baf2a7c28abbc692d9e7dd92cc
             uuid-1.3.13-3mVsma00PlkLLPrLVUhxJq=9189546b75a5e679abf4b8f1f323139c
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=67146f6b2fe2f883da537f78817eb0dd
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             network-ip-0.3.0.2-6AMB7LZoXGW5VNnZHhCQqV=485c9164a83e7e6dfc2d42d953cae629
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             loch-th-0.2.2-5Eq2dK8L8YJJWK4HNR9w70=00fd0dc72b72ed83b5d37907b4600d8e
             placeholders-0.1-4bE0Visrk2tFnTI1hMfyUR=c1d872831901a2463250620e0e797580
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=6440a7e70ad5450b51ffd7c9c4277ed3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-postgresql-binary/html/postgresql-binary.haddock
haddock-html: /usr/share/doc/haskell-postgresql-binary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
